import React$1 from 'react';
import * as react_jsx_runtime from 'react/jsx-runtime';

type CommonButtonProps = {
	children: React.ReactNode;
	kind?: "dark" | "light";
	focus?: "dark" | "light";
	fullWidth?: boolean;
	className?: string;
	raw?: boolean;
	noBorder?: boolean;
};

declare const Button: React$1.ForwardRefExoticComponent<{
    onClick?: React$1.MouseEventHandler<HTMLButtonElement> | undefined;
    disabled?: boolean | undefined;
    type?: "button" | "submit" | "reset" | undefined;
    slim?: boolean | undefined;
    size?: "small" | "medium" | "large" | undefined;
} & CommonButtonProps & React$1.ButtonHTMLAttributes<HTMLButtonElement> & React$1.RefAttributes<HTMLButtonElement>>;

declare const ButtonIcon: React$1.ForwardRefExoticComponent<{
    label?: string | undefined;
    children: React$1.ReactNode;
    size?: "small" | "medium" | "large" | undefined;
} & CommonButtonProps & React$1.ButtonHTMLAttributes<HTMLButtonElement> & React$1.RefAttributes<HTMLButtonElement>>;

declare const ButtonLink: React$1.ForwardRefExoticComponent<{
    children?: React$1.ReactNode;
    link?: string | undefined;
    target?: string | undefined;
    maxLabelLength?: number | undefined;
    slim?: boolean | undefined;
    size?: "small" | "medium" | "large" | undefined;
} & {
    onClick?: React$1.MouseEventHandler<HTMLButtonElement> | undefined;
    disabled?: boolean | undefined;
    type?: "button" | "submit" | "reset" | undefined;
    slim?: boolean | undefined;
    size?: "small" | "medium" | "large" | undefined;
} & CommonButtonProps & React$1.ButtonHTMLAttributes<HTMLButtonElement> & React$1.AnchorHTMLAttributes<HTMLAnchorElement> & React$1.RefAttributes<HTMLAnchorElement>>;

type FlexgridProps = {
	/**
	 * Children of the Flexgrid (FlexgridItem(s) or any other nodes).
	 */
	children: React.ReactNode;

	/**
	 * Equivalent to "justify-content" in flexbox, this prop defines
	 * the alignment along the main axis (horizontal).
	 */
	alignHorizontal?:
		| "normal"
		| "flex-start"
		| "center"
		| "flex-end"
		| "space-between"
		| "space-around"
		| "space-evenly";

	/**
	 * Equivalent to "align-items" in flexbox, this prop defines
	 * the alignment along the cross axis (vertical).
	 */
	alignVertical?:
		| "normal"
		| "flex-start"
		| "center"
		| "flex-end"
		| "stretch"
		| "baseline";

	/**
	 * The class name of the Flexgrid.
	 * It follows the [CSS class name property](https://developer.mozilla.org/en-US/docs/Web/CSS/class).
	 */
	className?: string;

	/**
	 * Width of the gutters between the columns.
	 * See the “Customization -> Spacing” section for
	 * more information about this unit.
	 */
	columnGap?: number;

	/**
	 * Equivalent to "flex-direction" in flexbox, this prop
	 * establishes the main-axis, thus defining the direction
	 * flex items are placed in the flex container. Flexbox is
	 * (aside from optional wrapping) a single-direction layout
	 * concept. Think of flex items as primarily laying out
	 * either in horizontal rows or vertical columns.
	 */
	direction?: "row" | "row-reverse" | "column" | "column-reverse";

	/**
	 * The height of the Flexgrid.
	 * It follows the [CSS height property](https://developer.mozilla.org/en-US/docs/Web/CSS/height).
	 */
	height?: string;

	/**
	 * Width of the gutters between the rows.
	 * See the “Customization -> Spacing” section for
	 * more information about this unit.
	 */
	rowGap?: number;

	/**
	 * The width of the Flexgrid.
	 * It follows the [CSS width property](https://developer.mozilla.org/en-US/docs/Web/CSS/width).
	 */
	width?: string;
};

type FlexgridItemProps = {
	/** Children of the FlexgridItem. */
	children?: React.ReactNode;

	/** Classname to apply to the FlexgridItem. */
	className?: string;

	/** The item will span across the provided number of grid tracks. */
	span?: number | "auto";
};

declare const Flexgrid: ({ children, className, columnGap, rowGap, height, width, direction, alignHorizontal, alignVertical, ...otherProps }: FlexgridProps) => react_jsx_runtime.JSX.Element;

/**
 * FlexgridItem is a child of Flexgrid. It is used to define the width of a
 * column in a Flexgrid. It can be used to span across multiple columns in a
 * Flexgrid by providing a number of columns or "auto" value to the `span` prop.
 */
declare const FlexgridItem: ({ children, className, span, ...otherProps }: FlexgridItemProps) => react_jsx_runtime.JSX.Element;

type FooterProps = {
	kind?: "dark" | "light";
	className?: string;
	noPaddings?: boolean;
	row1?: React.ReactNode;
	row2?: React.ReactNode;
};

declare const Footer: ({ className, kind, row1, row2, noPaddings, }: FooterProps) => react_jsx_runtime.JSX.Element;

type SpacingType =
	| undefined
	| string
	| number
	| {
			t?: number;
			r?: number;
			b?: number;
			l?: number;
	  };

interface IconsProps
	extends Omit<React.SVGAttributes<SVGElement>, "spacing"> {
	spacing?: SpacingType;
}

declare const IconClose: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconCopied: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconCopy: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconDelete: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconDog: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconDogInShield: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconEdit: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconHide: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconRestore: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconSettings: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconShow: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconUser: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

type MainProps = {
	children: React.ReactNode;
	className?: string;
	raw?: boolean;
};

declare const Main: ({ children, className, raw }: MainProps) => react_jsx_runtime.JSX.Element;

type TextInputProps = {
	label: string;
	name: string;
	labelId?: string;
	helperText?: string;
	error?: boolean;
	focusKind?: "dark" | "light";
	borderKind?: "dark" | "light";
	errorKind?: "dark" | "light";
	raw?: boolean;
	noBorder?: boolean;
	inputClassName?: string;
	rightElement?: React.ReactElement;
} & React.InputHTMLAttributes<HTMLInputElement>;

declare const TextInput: ({ id, name, label, error, raw, className, inputClassName, focusKind, borderKind, errorKind, disabled, noBorder, labelId, type, helperText, rightElement, ...extraProps }: TextInputProps) => react_jsx_runtime.JSX.Element;

export { Button, ButtonIcon, ButtonLink, Flexgrid, FlexgridItem, Footer, IconClose, IconCopied, IconCopy, IconDelete, IconDog, IconDogInShield, IconEdit, IconHide, IconRestore, IconSettings, IconShow, IconUser, Main, TextInput };
